function SkeMusMet_ParEst_Exer_Moderate_R_V10_CON
%******************************************************************************
%% This code is to provide the parameters of activation coefficients 
% of reaction and transport fluxes in Type I fibers in moderate intensity 
% exercise
%-------------------------------
%   In this V7_MOD_1 version, data is corresponding to Krustrup's CON group. 
% Especially, only type I fibers are activated. All of the enhancement 
% coefficients and activation coefficients in type II fibers are zero.
%   The enhancement coefficients for the volume change in type I fibers need 
% to be adjsuted to satisfy the constraint of total muscle conservation.  
%-------------------------------
% Last Modification: May 25  2011
%******************************************************************************

format long e
clear all
close all
clc
%******************************************************************************
%% Set the worload in the moderate intensity exercise
WR_Unload = 25;                   % Work rate for unloaded pedalling
WR_Cycle  = 115;                  % Work rate load on cycle ergometer for moderate intensity exercise (Approx. 35% VO2 max)
WR_Exer = WR_Unload + WR_Cycle;   % Total work rate for exercise
%******************************************************************************
% Define the enhancement coefficients for muscle volume and blood flow
% during exercise. Due to more muscle recruitment, effective muscle volume
% will increase . Both of the two parameters are obtained from literature.
%--------------------------------------------------------------------------
Qm_Rest = 0.9;                     % Resting muscle blood flow
Slope_Qm = 0.05;                   % Slope of activation for Q
Fact_Qm = (1 + (Slope_Qm/Qm_Rest) * WR_Exer);
Qm_Exer = Qm_Rest *  Fact_Qm;      % We assume it's constant 
% Note: Due to two musce fibers share a common blood domain, this
% coefficient has no change
%--------------------------------------------------------------------------
V_mus = 5.0;                       % Active muscle (quadricep femoris) volume at rest (L or Kg WW) (2 legs)
Slope_Vmus = 0.02;                 % Slope of activation for Vm [L/W]
Alpha_V_mus= (Slope_Vmus/V_mus);   % Enhancement coefficient 
Fact_Vmus = 1 + Alpha_V_mus * WR_Exer;  % Relative increase of tissue volume
Vm_ex = V_mus * Fact_Vmus;         % Effective muscle volume during exercise
%Note: These parameters are for whole muscle.
%--------------------------------------------------------------------------
% the change of blood domain. we use the same value as before for whole
% muscle
V_bl = 0.2*V_mus; 
V_bl_ex = V_bl*Fact_Vmus;

V_W= 0.4* V_mus;
%==========================================================================
%                            Type I Fibers 
%==========================================================================
V_R =  0.4*V_mus;               % Volume in Type I muscle 
%------------------------------------------------------------------------
Fact_Vmus_R =  (Vm_ex - V_W - V_bl_ex)/V_R;
Alpha_Vmus_R= (Fact_Vmus_R-1)/WR_Exer;
V_R_Exer = V_R * Fact_Vmus_R;          %Effective Type I fiber volume
%**************************************************************************
% Read resting uptake-release rates and reaction fluxes and also the transport
% and reaction parameters that were estimated from ischemia data analysis
%**************************************************************************
load Restingflux

URR0_R(1:50)   = Fluxes_R(1:50);
Rflux0_R(1:31) = Fluxes_R(51:81);

URR0_W(1:50)   = Fluxes_W(1:50);
Rflux0_W(1:31) = Fluxes_W(51:81);

%Define Fact_VO2
VO2m = 22.4*(Rflux0_R(28)+Rflux0_R(29)+Rflux0_W(28) +Rflux0_W(29))/2/1000;   % Resting muscle oxygen consumption (L/min)
Slope_VO2m = 0.9*0.01/VO2m;                                                 % Slope of activation for VO2m (L/min/Watt)

Fact_VO2m = 1 + (Slope_VO2m) * WR_Exer;      
%Note: in current model, assume all activated fluxes are proportional to
%VO2 in exercise
%---------------------------------------------------
Fact_Tmax_R = ones(50,1);
Fact_Lam_R  = ones(50,1);
Fact_Vmax_R = ones(31,1);
%==========================================================================
%                            Transport flux 
%--------------------------------------------------------------------------
%------------------Transport between Blood and Cytosol --------------------
Fact_Tmax_R(1) = 0.6*Fact_Qm;               %Glucose origin 1.5
Fact_Tmax_R(2) = 30*Fact_Qm;                %Pyruvate
Fact_Tmax_R(3) = 3.*Fact_Qm;               %Lac 0.16    
Fact_Tmax_R(6) = 0.5*Fact_Qm;               %FFA
Fact_Tmax_R(29)= 0.5*Fact_Qm;             % H
%+++++++++++++
Fact_Lam_R(4)  = 1*Fact_Qm;               % Ala
Fact_Lam_R(7)  =  4*Fact_Qm;              % CO2
Fact_Lam_R(8)  =  4*Fact_Qm;              % O2
%------------------------------------
%Species not actived 

Fact_Lam_R(5)  = 1;                       % Glr
%-----------------Transport between cytosol and mitochondria---------------
Fact_Lam_R(30)     = 4*Fact_Qm;           % O2
Fact_Lam_R(31)     = 4*Fact_Qm;           % CO2
Fact_Tmax_R(32)    = 5*Fact_VO2m;         % Pyr
Fact_Tmax_R(33)    = 0.3*Fact_VO2m;       % FAC
Fact_Tmax_R(34:35) = 0.85*Fact_VO2m;       % NADH NAD  
Fact_Tmax_R(36:38) = 0.6*Fact_VO2m;       % ATP ADP PI  
Fact_Tmax_R(39)    = 0.5*Fact_VO2m;       % CoA
Fact_Tmax_R(40)    = 0.5*Fact_VO2m;       % H
%==========================================================================
%                            Reaction Fluxes
%--------------------------------------------------------------------------
%--------------------------%Glycolysis-------------------------------------
Fact_Vmax_R(3)    = 9*Fact_VO2m;
Fact_Vmax_R(4)    = 5.5*Fact_VO2m;        % Glycogen breakdown
Fact_Vmax_R(5:10) = 1.9*Fact_VO2m;        % BPG->PEP->Pyr
% Fact_Vmax_R(5) = 1.9*Fact_VO2m;        % BPG->PEP->Pyr
Fact_Vmax_R(19)   = 0.5*Fact_VO2m;        % Alanine production 

%--------------------------%Lipid------------------------------------------
Fact_Vmax_R(12)   = 2*Fact_VO2m;         % Tgl breakdown     Note: close next
Fact_Vmax_R(15)   = 2*Fact_VO2m;         % FFA-FAC 
%-----------------------------%ATPase--------------------------------------
Fact_Vmax_R(16)   = 1.5*Fact_VO2m;  %2.75       %ATP uilization  
%-----------------------------%TCA-----------------------------------------
Fact_Vmax_R(20)   = 25*Fact_VO2m;       % PDH 
Fact_Vmax_R(21)   = 1.3*Fact_VO2m;       % Beta oxidation 
Fact_Vmax_R(22:27)= 0.50*Fact_VO2m;       % 1.0

%--------------------------%Oxidative Phosphorylation---------------------- 
Fact_Vmax_R(28)  = 1.95*Fact_VO2m;          % NADH 
Fact_Vmax_R(29)  = 1.95*Fact_VO2m;          % FADH2
Fact_Vmax_R(30)  = 0.20*Fact_VO2m;       % ATP synthesis 
%--------------------------------------------------------------------------
%Fluxes below are assumed "not activated". 
%--------------------------------------------------------------------------
Fact_Vmax_R(1)  =1;                      % Glc->G6P
Fact_Vmax_R(2)  =1;                      % G1P->G6P  new
%Fact_Vmax_R(3)  =1;                      % Glycogen Syn
Fact_Vmax_R(11) =1;                      % Pyr -> Lac
Fact_Vmax_R(12) =1;                      % Tgl breakdown
Fact_Vmax_R(13) =1;                      % GA3P->Gr3p   
Fact_Vmax_R(14) =1;                      % TGL syn try new
Fact_Vmax_R(17) =1;                      % ADK 
Fact_Vmax_R(18) =1;                      % PCR -> CR
%Fact_Vmax_R(19) =1;                      % Pyr->Ala  new
Fact_Vmax_R(31) =1;                      % H leakage

%**************************************************************************
%       This section define the anhancement and activation coefficients  
%**************************************************************************
Alpha_Qm =  (Fact_Qm-1)/WR_Exer;         % For whole tissue  
Alpha_Vmus = (Fact_Vmus-1)/WR_Exer;      % For whole tissue  
% set the enhancement coefficient of Type I fiber rrecruitment.
%**************************************************************************
%              Initial values for optimization 
%**************************************************************************
Alpha_r_R = zeros(31,1);     % Activation coefficients of reaction parameter
Alpha_t_R = zeros(50,1);     % Activation coefficients of transport parameters 
%---------------------Transport Flux---------------------------------------     
Alpha_t_R(1:3)  = (Fact_Tmax_R(1:3)-1)/WR_Exer;     %Glc, Pyr, LAc
Alpha_t_R(4:5)  = (Fact_Lam_R(4:5)-1)/WR_Exer;      %Ala, Glr
Alpha_t_R(6)    = (Fact_Tmax_R(6)-1)/WR_Exer;       %FFA
Alpha_t_R(7:8)  = (Fact_Lam_R(7:8)-1)/WR_Exer;      %CO2, O2
Alpha_t_R(29)   = (Fact_Tmax_R(29)-1)/WR_Exer;      %H

Alpha_t_R(30:31)= (Fact_Lam_R(30:31)-1)/WR_Exer;    %O2, CO2
Alpha_t_R(32:40)= (Fact_Tmax_R(32:40)-1)/WR_Exer;   %Pyr-H
%----------------------Reaction flux---------------------------------------
Alpha_r_R(1:31) = (Fact_Vmax_R(1:31)-1)/WR_Exer;   %Activation coefficients of reaction flux
%==========================================================================
%                            Final outputs
%==========================================================================

Alpha_t_R;

save theta_R.mat Alpha_t_R Alpha_r_R Alpha_Vmus Alpha_Vmus_R Alpha_Qm
% Activation_par_R=[Alpha_t_R;Alpha_r_R;Alpha_Vmus;Alpha_Vmus_R;Alpha_Qm]; 
% dlmwrite('InitialParameters_Activation_R.txt',Activation_par_R,'precision','%13.6d');
