function SkeMusMet_ParEst_Exer_Moderate_W

%******************************************************************************
% This code is to provide the parameters of activation coefficients of reaction
% and transport fluxes in Type II fibers in moderate intensity exercise
% In this new version, try to define different enhancement coefficient to
% activate different fiber- Muscle volume
%-------------------------------
% Last modification: Apr 26 , 2010
%**************************************************************************

format long e
clear all
close all
clc
%******************************************************************************
% Set the worload in the moderate intensity exercise
WR_Unload = 25;                      % Work rate for unloaded pedalling
WR_Cycle  = 115;                     % Work rate load on cycle ergometer for moderate intensity exercise (Approx. 35% VO2 max)
WR_Exer = WR_Unload + WR_Cycle; % Total work rate for exercise
%******************************************************************************
% Define the enhancement coefficients for muscle volume and blood flow
% during exercise. Due to more muscle recruitment, effective muscle volume
% will increase . Both of the two parameters are obtained from literature.
%--------------------------------------------------------------------------
V_mus = 5.0;                       % Active muscle (quadricep femoris) volume at rest (L or Kg WW) (2 legs)
Slope_Vmus = 0.02;                 % Slope of activation for Vm [L/W]
Alpha_V_mus= (Slope_Vmus/V_mus);   % Enhancement coefficient 
Fact_Vmus = 1 + Alpha_V_mus * WR_Exer;  % Relative increase of tissue volume
Vm_Exer = V_mus * Fact_Vmus;       % Effective muscle volume during exercise
%Note: These parameters are for whole muscle.
%--------------------------------------------------------------------------
Qm_Rest = 0.9;                       % Resting muscle blood flow
Slope_Qm = 0.05;                     % Slope of activation for Q
Fact_Qm = (1 + (Slope_Qm/Qm_Rest) * WR_Exer);
Qm_Exer = Qm_Rest *  Fact_Qm;        % We assume it's constant 
% Note: Due to two musce fibers share a common blood domain, this
% coefficient has no change
%==========================================================================
%                            Type II Fibers 
%==========================================================================
V_W =  0.384*V_mus;                 % Volume in Type II muscle 
%------------------------------------------------------------------------
%Alpha_Vmus_W = 0.003;                % Slope of activation for Vm [L/W]
Alpha_Vmus_W = 0.003;                % Slope of activation for Vm [L/W]
%Alpha_Vmus_W = 0;

Fact_Vmus_W = 1 + Alpha_Vmus_W * WR_Exer;
V_W_Exer = V_W * Fact_Vmus_W;       %Effective volume
%**************************************************************************
% Read resting uptake-release rates and reaction fluxes and also the transport
% and reaction parameters that were estimated from ischemia data analysis
%**************************************************************************
load Restingflux
URR0_R(1:50)   = Fluxes_R(1:50);
Rflux0_R(1:31) = Fluxes_R(51:81);

URR0_W(1:50)   = Fluxes_W(1:50);
Rflux0_W(1:31) = Fluxes_W(51:81);

%Define Fact_VO2
VO2m = 22.4*(Rflux0_R(28)+Rflux0_R(29)+Rflux0_W(28) +Rflux0_W(29))/2/1000;   % Resting muscle oxygen consumption (L/min)
Slope_VO2m = 0.9*0.01/VO2m;                                                 % Slope of activation for VO2m (L/min/Watt)

Fact_VO2m = 1 + (Slope_VO2m) * WR_Exer;      
%---------------------------------------------------
Fact_Tmax_W = ones(50,1);
Fact_Lam_W  = ones(50,1);
Fact_Vmax_W = ones(31,1);
%==========================================================================
%                            Transport flux 
%--------------------------------------------------------------------------
%------------------Transport between Blood and Cytosol --------------------
Fact_Tmax_W(1) = 0.35*Fact_Qm;           %Glucose origin 1.5
Fact_Tmax_W(2) = 1.5*Fact_Qm;              %Pyruvate
Fact_Tmax_W(3) = 2*Fact_Qm;            %Lac 0.16    
Fact_Tmax_W(6) = 0.5*Fact_Qm;            %FFA
Fact_Tmax_W(29) = 1*Fact_Qm;            %H
%+++++++++++++
Fact_Lam_W(7) =  2*Fact_Qm;              %CO2
Fact_Lam_W(8) =  2*Fact_Qm;              %O2
%------------------------------------
%Species not actived 
Fact_Lam_W(4) = 1;                       %Ala
Fact_Lam_W(5) = 1;                       %Glr
%-----------------Transport between cytosol and mitochondria---------------
Fact_Lam_W(30) = 2*Fact_Qm;              %O2
Fact_Lam_W(31) = 2*Fact_Qm;              %CO2
Fact_Tmax_W(32)    = 1.3*Fact_VO2m;      %Pyr
Fact_Tmax_W(33)    = 0.3*Fact_VO2m;      %FAC
Fact_Tmax_W(34:35) = 0.4*Fact_VO2m;     %NADH NAD  
Fact_Tmax_W(36:38) = 0.4*Fact_VO2m;        %ATP ADP PI  
Fact_Tmax_W(39)    = 0.5*Fact_VO2m;        %CoA
Fact_Tmax_W(40)    = 0.5*Fact_VO2m;        %H
Fact_Tmax_W(42)    = 0.5*Fact_VO2m;        %Citrate
Fact_Tmax_W(46)    = 0.5*Fact_VO2m;        %Malate
%==========================================================================
%                            Reaction Fluxes
%--------------------------------------------------------------------------
%-------------------------5-%Glycolysis-------------------------------------
Fact_Vmax_W(3) = 2*Fact_VO2m;
Fact_Vmax_W(4)   = 0.91*Fact_VO2m;        % Glycogen breakdown
Fact_Vmax_W(5:10)= 0.80*Fact_VO2m;        % BPG->PEP->Pyr
%--------------------------%Lipid------------------------------------------
Fact_Vmax_W(12) = 0.2*Fact_VO2m;         % Tgl breakdown     Note: close next
Fact_Vmax_W(15) = 0.2*Fact_VO2m;         % FFA-FAC 
%-----------------------------%ATPase--------------------------------------
Fact_Vmax_W(16) = 1.*Fact_VO2m;    %1.8     %ATP uilization  
%-----------------------------%TCA-----------------------------------------
Fact_Vmax_W(20)   = 7*Fact_VO2m;       % PDH 
Fact_Vmax_W(21)   = 0.08*Fact_VO2m;       % Beta oxidation 
Fact_Vmax_W(22:27)= 0.3*Fact_VO2m;       % 1.0
%--------------------------%Oxidative Phosphorylation---------------------- 
Fact_Vmax_W(28)  = 0.5*Fact_VO2m;          % NADH 
Fact_Vmax_W(29)  = 0.5*Fact_VO2m;          % FADH2
Fact_Vmax_W(30)  = 0.2*Fact_VO2m;       % ATP synthesis 
%--------------------------------------------------------------------------
%Fluxes below are assumed "not activated". 
%--------------------------------------------------------------------------
Fact_Vmax_W(1)  =1;                      % Glc->G6P
Fact_Vmax_W(2)  =1;                      % G1P->G6P  new
%Fact_Vmax_W(3)  =1;                      % Glycogen Syn
Fact_Vmax_W(11) =1;                      % Pyr -> Lac
Fact_Vmax_W(12) =1;                      % Tgl breakdown
Fact_Vmax_W(13) =1;                      % GA3P->Gr3p   
Fact_Vmax_W(14) =1;                      % TGL syn try new
Fact_Vmax_W(17) =1;                      % ADK 
Fact_Vmax_W(18) =1;                      % PCR -> CR
Fact_Vmax_W(19) =1;                      % Pyr->Ala  new
Fact_Vmax_W(31) =1;                      % H leakage
%**************************************************************************
%       This section define the activation coefficients  
%**************************************************************************


%**************************************************************************
%        Initial values for optimization 
%**************************************************************************
Alpha_r_W = zeros(31,1);     % Activation coefficients of reaction parameter
Alpha_t_W = zeros(50,1);     % Activation coefficients of transport parameters 
%---------------------Transport Flux---------------------------------------     
Alpha_t_W(1:3)  = (Fact_Tmax_W(1:3)-1)/WR_Exer;     %Glc, Pyr, LAc
Alpha_t_W(4:5)  = (Fact_Lam_W(4:5)-1)/WR_Exer;      %Ala, Glr
Alpha_t_W(6)    = (Fact_Tmax_W(6)-1)/WR_Exer;       %FFA
Alpha_t_W(7:8)  = (Fact_Lam_W(7:8)-1)/WR_Exer;      %CO2, O2
Alpha_t_W(29)   = (Fact_Tmax_W(29)-1)/WR_Exer;      %H

Alpha_t_W(30:31)= (Fact_Lam_W(30:31)-1)/WR_Exer;    %O2, CO2
Alpha_t_W(32:40)= (Fact_Tmax_W(32:40)-1)/WR_Exer;   %Pyr-H
%----------------------Reaction flux---------------------------------------
Alpha_r_W(1:31) = (Fact_Vmax_W(1:31)-1)/WR_Exer;   %Activation coefficients of reaction flux

Alpha_t_W(:)=0;
Alpha_r_W(:)=0;
Alpha_Vmus_W=0;
save theta_W.mat Alpha_t_W Alpha_r_W Alpha_Vmus_W
%==========================================================================
%                            Final outputs
%==========================================================================

% Activation_par_W=[Alpha_t_W;Alpha_r_W;Alpha_Vmus_W]; 
% dlmwrite('InitialParameters_Activation_W.txt',Activation_par_W,'precision','%13.6d');
