function SkeMusMet_ParEst_Rest_NASA_normal_V8
%******************************************************************************
% This code is to perform the flux balance analysis for " Normal muscle" and 
% set the species concentration in each fibers and parameters in transport and
% reaction fluxes.. No differences between the two muscle fibers. 

% Latest modified on May 15, 2011 
%******************************************************************************
format long e
clear all
close all
clc
%**************************************************************************
% This section defines the blood, volumes of total muscle, volume of each 
% subdomain in each fiber
%**************************************************************************
%                  The Vm and blood flow for whole tissue
%--------------------------------------------------------------------------
V_mus = 5.0;                % Active muscle (quadricep femoris) volume at rest (L or Kg WW) (1 legs)
Qm = 0.9;                   % Active muscle (quadricep femoris) blood flow at rest (L/min) (1 legs)
%--------------------------------------------------------------------------
%                        Volume of blood domain
%--------------------------------------------------------------------------
Vb = 0.07* V_mus;           % Capillary blood volume 
Visf = 0.13*V_mus;          % Interstitial fluid volume
%--------------------------------------------------------------------------
%                  Volume of each domain in Type I muscle fiber
%--------------------------------------------------------------------------
V_R     = 0.4*V_mus;        % Volume in Type I muscle 
V_cyt_R = 0.352*V_mus;      % Cytosol volume in Type I muscle 
V_mit_R = 0.048*V_mus;      % Mitochondria volume in Type I muscle 
%--------------------------------------------------------------------------
%                  Volume of each domain in Type II muscle fiber
%--------------------------------------------------------------------------
V_W     = 0.4*V_mus;         % Volume in Type II 
V_cyt_W = 0.368*V_mus;       % Cytosol muscle volume in Type II 
V_mit_W = 0.032*V_mus;       % Mitochondria muscle volume in Type II 
%**************************************************************************
% This section defines transport rate based on the uptake-relese rate(URR) 
% (equal to the Q*AV differences) 
% [units: mmol/min].
%**************************************************************************
% The first 8 transport fluxes involving the exchanges between blood and
% tissue; and URR(30-40, 42, 44) transport fluxes involving exchange between
% cytosol and mitochondria.
 
% URR Values of the initial 6 species URR(1-6) are obtained from the literature. 
% CO2 release rate is calculated from the the flux rate of CO2 production in 
% tissue in flux balance equation; O2 uptake rate is calculated from the 
% flux rate of NADH and FADH2 flux balance equation.  

% Uptake/release rate for whole tissue is the sum of uptake/release rate
% for each fiber. URR rates between blood and tissue for each fiber are 
% estimated based on the constaints of RQ(respiratory quotient).
%--------------------------------------------------------------------------
%                    Uptake/Release rate for whole tissue 
%--------------------------------------------------------------------------
URR = zeros(50,1);               % URR for whole tissue- array inilization 
URR(1) = 0.195;                  % Glucose uptake by quadricep femoris muscle
URR(2) = 0.012;                  % Pyruvate uptake by quadricep femoris muscle
URR(3) = -0.09;                  % Lactate release by quadricep femoris muscle
URR(4) = -0.065;                 % Alanine release by quadricep femoris muscle
URR(5) = -0.008;                 % Glycerol release by quadricep femoris muscle
URR(6) =  0.073;                 % Fatty acid uptake by quadricep femoris muscle

URR(7) = - (6*URR(1) + 3*URR(2)+ 3*URR(3) + 16*URR(6) + 3*URR(4) + 3*URR(5));      % CO2 release 
URR(8) = (6*URR(1) + 2.5*URR(2) + 3*URR(3) + 2.5*URR(4) + 3.5*URR(5) + 23*URR(6)); % O2 uptake 

URR7 = 22.4*URR(7);              % CO2 release in the unit of ml/min
URR8 = 22.4*URR(8);              % O2 uptake in the unit of ml/min
RQ = - URR(7)/URR(8);            % Respiratory quotient of whole tissue (unitless)

%--------------------------------------------------------------------------
%             the Uptake/Release rate for Type 1 fibers
%--------------------------------------------------------------------------
URR_R = zeros(50,1);             % URR for Type I fiber - array inilization
%--------------------------------------------------------------------------
% New distribution, which is to reduce the URR_R/URR_W ratios 
URR_R(1:6) = URR(1:6)/2;

URR_R(7) = - (6*URR_R(1) + 3*URR_R(2)+ 3*URR_R(3) + 16*URR_R(6) + 3*URR_R(4) + 3*URR_R(5));      % CO2 release 
URR_R(8) = (6*URR_R(1) + 2.5*URR_R(2) + 3*URR_R(3) + 2.5*URR_R(4) + 3.5*URR_R(5) + 23*URR_R(6)); % O2 uptake 

URR7_R = 22.4*URR_R(7);          % CO2 release in the unit of ml/min
URR8_R = 22.4*URR_R(8);          % O2 uptake in the unit of ml/min
RQ_R = - URR_R(7)/URR_R(8);      % Respiratory quotient of Type I (unitless)
%==========================================================================
100-URR_R(1:6)./URR(1:6)*100;    % Calculate the percent 
%==========================================================================
%--------------------------------------------------------------------------
%    Calculate the Uptake/Release rate for Type 2 fibers. 
%--------------------------------------------------------------------------
URR_W = zeros(50,1);             % URR for Type II fiber- arrzy inilization
URR_W(1) = URR(1)-URR_R(1);      % Glucose uptake by quadricep femoris muscle
URR_W(2) = URR(2)-URR_R(2);      % Pyruvate uptake by quadricep femoris muscle
URR_W(3) = URR(3)-URR_R(3);      % Lactate release by quadricep femoris muscle
URR_W(4) = URR(4)-URR_R(4);      % Alanine release by quadricep femoris muscle
URR_W(5) = URR(5)-URR_R(5);      % Glycerol release by quadricep femoris muscle
URR_W(6) = URR(6)-URR_R(6);      % Fatty acid uptake by quadricep femoris muscle
%--------------------------------------------------------------------------
URR_W(7) = - (6*URR_W(1) + 3*URR_W(2)+ 3*URR_W(3) + 16*URR_W(6) + 3*URR_W(4) + 3*URR_W(5));       % CO2 release 
URR_W(8) = (6*URR_W(1) + 2.5*URR_W(2) + 3*URR_W(3) + 2.5*URR_W(4) + 3.5*URR_W(5) + 23*URR_W(6));  % O2 uptake 

URR7_W = 22.4*URR_W(7);          % CO2 release in the unit of ml/min
URR8_W = 22.4*URR_W(8);          % O2 uptake in the unit of ml/min
RQ_W = - URR_W(7)/URR_W(8);      % Respiratory quotient of Type II  (unitless)
%--------------------------------------------------------------------------
URR_R(7)+ URR_W(7);              % Total CO2 release in whole muscle 
URR_R(8)+ URR_W(8);              % Total O2 uptake in whole muscle    
%******************************************************************************
% This section calcuates  the metabolic reaction fluxes from the transport 
% fluxes using the flux balance analysis in each msucle fiber by calling 
% subroutines. The reaction fluxes which can not be obtained from flux 
% balance analysis is obtained from the literature (glycogen synthase and 
% phosphorylation. The equation show net reaction.
% Units: mmol/min
%******************************************************************************
Rflux_R = zeros(31,1);           % Reaction flux in Type 1 muscle fibers 
Rflux_W = zeros(31,1);           % Reaction flux in Type 2 muscle fibers 

[Rflux_R,URR_R] = Sub_FluxBalance(URR_R);    % Flux balance analysis 
[Rflux_W,URR_W] = Sub_FluxBalance(URR_W);    % Flux balance analysis 
%--------------------------------------------------------------------------
Fluxes_R = [URR_R;Rflux_R];      % The array of total flux 
Fluxes_W = [URR_W;Rflux_W];
save Restingflux Fluxes_R Fluxes_W
% dlmwrite('RestingFluxes_R.txt',Fluxes_R, 'precision','%13.6d');
% dlmwrite('RestingFluxes_W.txt',Fluxes_W, 'precision','%13.6d');
%******************************************************************************
% This section sets the arterial blood concentration of the species which
% undergo the blood-tissue exchange. 

% Values are based on the experimental data. The values of O2 and CO2 are
% calculated by incorporating the free-bound relationship with hemoglobin
% and bicarbonate buffer for CO2, etc based on the O2 and CO2 tension.
% Proton concentration is calculated from the pH value. Here we assume pH 
% in RBC = 7.24 and pH in plasma = 7.4 
% [units: mmol/L (mM)].
%******************************************************************************
% Calculation of total O2 and CO2 concentrations in arterial blood through
% the functions O2Tot_Blood and CO2Tot_Blood
%--------------------------------------------------------------------------
alphaO2 = 1.35e-3;           % Solubility of O2 in blood (mM/mmHg)
alphaCO2 = 3.05e-2;          % Solubility of CO2 in blood (mM/mmHg)
PO2a = 100;                  % Arterial PO2 (mmHg)
PCO2a = 40;                  % Arterial PCO2 (mmHg)
O2a = alphaO2*PO2a;          % Arterial Free O2 Concentration
CO2a = alphaCO2*PCO2a;       % Arterial Free CO2 Concentration
[SHbO2a,CHbO2a,O2aTot] = O2Tot_Blood(O2a);
[SHbCO2a,CHbCO2a,CHCO3a,CO2aTot] = CO2Tot_Blood(CO2a);
O2a_all = [PO2a,O2a,SHbO2a,CHbO2a,O2aTot];                % Print
CO2a_all = [PCO2a,CO2a,SHbCO2a,CHbCO2a,CHCO3a,CO2aTot];   % Print
%--------------------------------------------------------------------------
Ca = zeros(9,1);             % Initialization of Cart
Ca(1) = 5.0;                 % Arterial Glucose 
Ca(2) = 0.08;                % Arterial Pyruvate 0.075
Ca(3) = 0.50;                % Arterial Lactate
Ca(4) = 0.25;                % Arterial Alanine
Ca(5) = 0.04;                % Arterial Glycerol
Ca(6) = 0.7;                 % Arterial Free Fatty Acid
Ca(7) = CO2a;                % Arterial Free CO2
Ca(8) = O2a;                 % Arterial Free O2
Ca(9) = 10^(-7.4)*1000;      % Arterial H, pH 7.4
Ca;
%******************************************************************************
% This section calculate the species concentration at capillary and venous
% blood. Here we assume it's well mixted in blood and C_bl = C_ven.

% The calculation is based on the URR data using the AV difference formulas
% [units: mmol/L (mM)].

% Because two muscle fibers share the same blood domain, the species
% concentration in blood are same and calculated from the balance of AV 
% difference and URR for whole tissue (sum of two fibers), and then the values
% are same as before.     
%******************************************************************************
% Calculation of total O2 and CO2 concentrations in capillary/venous blood 
% from uptake-release rates of O2 and CO2.
%-------------------------------------------------------------------------
CO2bTot = CO2aTot - URR(7)/Qm;                          % Venous Total CO2 
O2bTot = O2aTot - URR(8)/Qm;                            % Venous Total O2
%--------------------------------------------------------------------------
% Calculation of free O2 and CO2 concentrations in capillary/venous blood from 
% total O2 and CO2 concentrations. Use the Newton-Raphson's method of root 
% finding for the inversion (O2_Blood and CO2_Blood).
%--------------------------------------------------------------------------
[O2b,SHbO2b,CHbO2b] = O2_Blood(O2bTot);
[CO2b,SHbCO2b,CHbCO2b,CHCO3b] = CO2_Blood(CO2bTot);

PO2b = O2b/alphaO2;                                     % Venous PO2
PCO2b = CO2b/alphaCO2;                                  % Venous PCO2

O2b_all = [PO2b,O2b,SHbO2b,CHbO2b,O2bTot];              % Print
CO2b_all = [PCO2b,CO2b,SHbCO2b,CHbCO2b,CHCO3b,CO2bTot]; % Print
%--------------------------------------------------------------------------
%Calculate the blood concentration
%--------------------------------------------------------------------------
Cb = zeros(9,1);                   % Initialization of Cb array

Cb(1) = Ca(1) - URR(1)/Qm;         % Capillary/Venous Glucose
Cb(2) = Ca(2) - URR(2)/Qm;         % Capillary/Venous Pyrvate
Cb(3) = Ca(3) - URR(3)/Qm;         % Capillary/Venous Lactate
Cb(4) = Ca(4) - URR(4)/Qm;         % Capillary/Venous Alanine
Cb(5) = Ca(5) - URR(5)/Qm;         % Capillary/Venous Glycerol
Cb(6) = Ca(6) - URR(6)/Qm;         % Capillary/Venous Free Fatty acid
Cb(7) = CO2b;                      % Capillary/Venous Free CO2
Cb(8) = O2b;                       % Capillary/Venous Free O2
Cb(9) = 10^(-7.32)*1000;           % Capillary/Venous H   pH 7.32
Cb;
%**************************************************************************
% This section sets the species concentration in tissue
%*************************************************************************
% Calculation of total O2 and CO2 concentrations in tissue cytosol through 
% the functions O2Tot_Cells and CO2Tot_Cells. Here assume myoglobin only 
% exist in mitochondria and only free O2 and CO2 exist in cytosol. 
%--------------------------------------------------------------------------
PO2c = 25;                 % Cytosol PO2 (mmHg)
PCO2c = 46;                % Cytosol PCO2 (mmHg)
O2c = alphaO2*PO2c;        % Cytosol Free O2 Concentration (mM)
CO2c = alphaCO2*PCO2c;     % Cytosol Free CO2 Concentration (mM)
%--------------------------------------------------------------------------
% Calculation of total O2 and CO2 concentrations in tissue mitochondria through 
% the functions O2Tot_Cells and CO2Tot_Cells.
%--------------------------------------------------------------------------
PO2m =  20;                % Mitochondria PO2 (mmHg)
PCO2m = 50;                % Mitochondria PCO2 (mmHg)

O2m = alphaO2*PO2m;        % Mitochondria Free O2 Concentration (mM)
CO2m = alphaCO2*PCO2m;     % Mitochondria Free CO2 Concentration (mM)

[SMbO2m,CMbO2m,O2mTot] = O2Tot_Cells(O2m);
[CHCO3m,CO2mTot] = CO2Tot_Cells(CO2m);
O2m_all = [O2m,SMbO2m,CMbO2m,O2mTot];           % For printing
CO2m_all = [CO2m,CHCO3m,CO2mTot];               % For printing

Hct = 0.45;                % Standard hematocrit (ml/ml)
CHbTot = 5.2;              % Concentration of hemoglobin in RBC (mM)
CMbTot = 0.5;              % Concentration of myoglobin (mM)
% StO2 = (Vb/2*CHbO2b/4 + V_m*CMbO2m)/(Vb/2*Hct*CHbTot + V_m*CMbTot);  
% StO2 = (Vb/2*CHbO2b/4 + V_m_R*CMbO2m +  V_m_W*CMbO2m)...
%      /(Vb/2*Hct*CHbTot + V_m_R*CMbTot+ V_m_W*CMbTot)

%******************************************************************************
% This section sets the resting,steady state tissue concentrations of all the
% species (substrates, intermediate metabolites and controllers) in two fibers
% of skeletal muscle. They are experimental values obtained from biopsies/NMR. 
% Units: mmol/kg wet weight (kg wet weight = L; assuming density = 1)
% The distribution of species between two fibers and between cytosol and
% mitochondria is estimated. 
%    The concentrations are generated from subroutine
%******************************************************************************
Cc_R = zeros(50,1);         
Cc_W = zeros(50,1);

load Cc0_tissue 
save Cc0.mat Ca Cb Cc_R Cc_W V_mus Qm
%******************************************************************************
% This section computes and sets the transport parameters for species  
% involving exchange between blood and tissue and species transport 
% between cytosol and mitochondria. 

% The MM constant in carrier transport for blood-cytosol are obtained from
% literature; for cytosol- mitochondria is estimated from the concentration
% of Cc. We further assume the MM constant for two muscle fibers are same.
% So does it for MM constant for reaction fluxes. [mmol/l]
%******************************************************************************
Tmax_R = zeros(50,1);         % Maximal coefficients of carrier mediated transport  
Mm_R   = zeros(50,1);         % MM constant of carrier mediated transport  
Lam_R  = zeros(50,1);         % Coefficients for passive transport =(P*S)
Diff_R = zeros(50,1);         % Variables in related calculation

Tmax_W = zeros(50,1);
Mm_W   = zeros(50,1);
Lam_W  = zeros(50,1);
Diff_W = zeros(50,1);
%==========================================================================
theta = dlmread('EstimatedParameters_0726.txt'); 
% we assume the Mm parameters are same as before 
Mm_R(:) =theta(51:100);
%==========================================================================
%                            Type 1
%==========================================================================
%               Between blood and cytosol
%******************************************************************************
% Calculation of uptake and release rates of facilitated diffusion 
% Mm_R(1) = 2.5;                         % MM constant for uptake of GLU from blood
% Mm_R(2) = 1.0;                         % MM constant for uptake of Pyr from blood
% Mm_R(3) = 5.0;                         % MM constant for release of LAC to blood
% Mm_R(6) = 1.0;                         % MM constant for release of FFA to blood
% Mm_R(29)= Cb(9);                       % MM constant for release of H to blood

Diff_R(1) = Cb(1)/(Mm_R(1) + Cb(1)) - Cc_R(1)/(Mm_R(1)+Cc_R(1));
Diff_R(2) = Cb(2)/(Mm_R(2) + Cb(2)) - Cc_R(2)/(Mm_R(2)+Cc_R(2));
Diff_R(3) = Cb(3)/(Mm_R(3) + Cb(3)) - Cc_R(3)/(Mm_R(3)+Cc_R(3));
Diff_R(6) = Cb(6)/(Mm_R(6) + Cb(6)) - Cc_R(6)/(Mm_R(6)+Cc_R(6));
Diff_R(29)= Cb(9)/(Mm_R(29)+ Cb(9)) - Cc_R(29)/(Mm_R(29)+Cc_R(29));

Tmax_R(1) = URR_R(1)/Diff_R(1);        % Tmax for uptake of GLU from blood
Tmax_R(2) = URR_R(2)/Diff_R(2);        % Tmax for uptake of Pyr from blood
Tmax_R(3) = URR_R(3)/Diff_R(3);        % Tmax for release of LAC to blood
Tmax_R(6) = URR_R(6)/Diff_R(6);        % Tmax for uptake of FFA from blood
Tmax_R(29)= URR_R(29)/Diff_R(29);      % Tmax for release of H from blood

% Calculation of the passive transport parameters...
Diff_R(4) = (Cb(4) - Cc_R(4));
Diff_R(5) = (Cb(5) - Cc_R(5));
Diff_R(7) = (Cb(7) - Cc_R(7));
Diff_R(8) = (Cb(8) - Cc_R(8));

Lam_R(4) = URR_R(4)/Diff_R(4);         % Lambda for release of ALA to blood
Lam_R(5) = URR_R(5)/Diff_R(5);         % Lambda for release of GLC to blood
Lam_R(7) = URR_R(7)/Diff_R(7);         % Lambda for release of CO2 to blood
Lam_R(8) = URR_R(8)/Diff_R(8);         % Lambda for uptake of O2 from blood
%--------------------------------------------------------------------------
% Mm_R(32) = Cc_R(32);                    % MM constant for Pyr enter mitochondria
% Mm_R(33) = Cc_R(33);                   % MM constant for FAC enter mitochondria
% Mm_R(34) = Cc_R(27)/Cc_R(28)/3;        % MM constant for NADH/NAD enter mitochondria
% Mm_R(35) = Cc_R(34)/Cc_R(35)*100;      % MM constant for NADH/NAD leave mitochondria
% Mm_R(36) = Cc_R(22)/Cc_R(23)*2;        % Mm constant for ATP/ADP transport 
% Mm_R(37) = Cc_R(36)/Cc_R(37)/2;        % Mm constant for ATP/ADP transport 
% Mm_R(38) = Cc_R(38);                   % MM constant for Pi enter mitochondria
% Mm_R(39) = Cc_R(39);                   % MM constant for CoA enter mitochondria
% Mm_R(40) = Cc_R(40);                   % MM constant for H+ enter mitochondria

Diff_R(30) = (Cc_R(8) - Cc_R(30));     % O2
Diff_R(31) = (Cc_R(7) - Cc_R(31));     % CO2

Diff_R(32) = Cc_R(2) /(Mm_R(32)+Cc_R(2))  - Cc_R(32)/(Mm_R(32)+Cc_R(32));       % Pyruvate
Diff_R(33) = (Cc_R(19)/(Mm_R(33)+Cc_R(19)) - Cc_R(33)/(Mm_R(33)+Cc_R(33)));     % FAC
Diff_R(34) = (Cc_R(27)/Cc_R(28))/(Mm_R(34)+ Cc_R(27)/Cc_R(28)) ... 
            -(Cc_R(34)/Cc_R(35))/(Mm_R(35)+ Cc_R(34)/Cc_R(35));                 % NADH
Diff_R(35) = -Diff_R(34);                                                       % NAD
Diff_R(36) = (Cc_R(22)/Cc_R(23))/(Mm_R(36)+ Cc_R(22)/Cc_R(23))-...              % ATP
             (Cc_R(36)/Cc_R(37))/(Mm_R(37)+ Cc_R(36)/Cc_R(37));
Diff_R(37) = -Diff_R(36);                                                       % ADP
Diff_R(38) = Cc_R(25)/(Mm_R(38)+Cc_R(25)) - Cc_R(38)/(Mm_R(38)+Cc_R(38));       % Pi
Diff_R(39) = Cc_R(26)/(Mm_R(39)+Cc_R(26)) - Cc_R(39)/(Mm_R(39)+Cc_R(39));       % CoA
Diff_R(40) = Cc_R(29)/(Mm_R(40)+Cc_R(29)) - Cc_R(40)/(Mm_R(40)+Cc_R(40));       % H

Lam_R(30)  = URR_R(30)/Diff_R(30);     % Lambda for O2 entering Mitochondria 
Lam_R(31)  = URR_R(31)/Diff_R(31);     % Lambda for CO2 leaveing Mitochondria 
Tmax_R(32) = URR_R(32)/Diff_R(32);     % Tmax for Pyr entering Mitochondria
Tmax_R(33) = URR_R(33)/Diff_R(33);     % Tmax for FAC entering Mitochondria
Tmax_R(34) = URR_R(34)/Diff_R(34);     % Tmax for NADH/NAD entering Mitochondria
Tmax_R(35) = URR_R(35)/Diff_R(35);     % Tmax for NADH/NAD leaveing Mitochondria 
Tmax_R(36) = URR_R(36)/Diff_R(36);     % Tmax for ATP leaveing Mitochondria 
Tmax_R(37) = URR_R(37)/Diff_R(37);     % Tmax for ADP entering Mitochondria
Tmax_R(38) = URR_R(38)/Diff_R(38);     % Tmax for Pi entering Mitochondria
Tmax_R(39) = URR_R(39)/Diff_R(39);     % Tmax for CoA leaveing Mitochondria 
Tmax_R(40) = URR_R(40)/Diff_R(40);     % Tmax for H leaveing Mitochondria 
%==========================================================================
%                            Type 2
%==========================================================================
%                 Between blood and cytosol
%--------------------------------------------------------------------------
%Note: Here we assume transport coefficients are same in both two type
%fibers
Mm_W(:) = Mm_R(:);
% Calculation of the parameter  
Diff_W(1) = Cb(1)/(Mm_W(1) + Cb(1)) - Cc_W(1)/(Mm_W(1)+Cc_W(1));
Diff_W(2) = Cb(2)/(Mm_W(2) + Cb(2)) - Cc_W(2)/(Mm_W(2)+Cc_W(2));
Diff_W(3) = Cb(3)/(Mm_W(3) + Cb(3)) - Cc_W(3)/(Mm_W(3)+Cc_W(3));
Diff_W(6) = Cb(6)/(Mm_W(6) + Cb(6)) - Cc_W(6)/(Mm_W(6)+Cc_W(6));
Diff_W(29)= Cb(9)/(Mm_W(29)+ Cb(9)) - Cc_W(29)/(Mm_W(29)+Cc_W(29));

Tmax_W(1) = URR_W(1)/Diff_W(1);        % Tmax for uptake of GLU from blood
Tmax_W(2) = URR_W(2)/Diff_W(2);        % Tmax for uptake of Pyr from blood
Tmax_W(3) = URR_W(3)/Diff_W(3);        % Tmax for release of LAC to blood
Tmax_W(6) = URR_W(6)/Diff_W(6);        % Tmax for uptake of FFA from blood
Tmax_W(29)= URR_W(29)/Diff_W(29);      % Tmax for release of H from blood

% Calculation of the passive transport parameters...
Diff_W(4) = (Cb(4) - Cc_W(4));
Diff_W(5) = (Cb(5) - Cc_W(5));
Diff_W(7) = (Cb(7) - Cc_W(7));
Diff_W(8) = (Cb(8) - Cc_W(8));
Lam_W(4)  = URR_W(4)/Diff_W(4);        % Lambda for release of ALA to blood
Lam_W(5)  = URR_W(5)/Diff_W(5);        % Lambda for release of GLC to blood
Lam_W(7)  = URR_W(7)/Diff_W(7);        % Lambda for release of CO2 to blood
Lam_W(8)  = URR_W(8)/Diff_W(8);        % Lambda for uptake of O2 from blood
%--------------------------------------------------------------------------
Diff_W(30) = (Cc_W(8) - Cc_W(30));     % O2
Diff_W(31) = (Cc_W(7) - Cc_W(31));     % CO2
Diff_W(32) = Cc_W(2) /(Mm_W(32)+Cc_W(2))  - Cc_W(32)/(Mm_W(32)+Cc_W(32));     % Pyruvate
Diff_W(33) = (Cc_W(19)/(Mm_W(33)+Cc_W(19)) - Cc_W(33)/(Mm_W(33)+Cc_W(33)));   % FAC
Diff_W(34) = (Cc_W(27)/Cc_W(28))/(Mm_W(34)+ Cc_W(27)/Cc_W(28)) ... 
            -(Cc_W(34)/Cc_W(35))/(Mm_W(35)+ Cc_W(34)/Cc_W(35));               % NADH
Diff_W(35) = -Diff_W(34);                                                     % NAD
Diff_W(36) = (Cc_W(22)/Cc_W(23))/(Mm_W(36)+ Cc_W(22)/Cc_W(23))-...            % ATP
             (Cc_W(36)/Cc_W(37))/(Mm_W(37)+ Cc_W(36)/Cc_W(37));
Diff_W(37) = -Diff_W(36);                                                     % ADP
Diff_W(38) = Cc_W(25)/(Mm_W(38)+Cc_W(25)) - Cc_W(38)/(Mm_W(38)+Cc_W(38));     % PI
Diff_W(39) = Cc_W(26)/(Mm_W(39)+Cc_W(26)) - Cc_W(39)/(Mm_W(39)+Cc_W(39));     % CoA
Diff_W(40) = Cc_W(29)/(Mm_W(40)+Cc_W(29)) - Cc_W(40)/(Mm_W(40)+Cc_W(40));     % H

Lam_W(30)  = URR_W(30)/Diff_W(30);     % Lambda for O2 entering Mitochondria 
Lam_W(31)  = URR_W(31)/Diff_W(31);     % Lambda for CO2 leaveing Mitochondria 
Tmax_W(32) = URR_W(32)/Diff_W(32);     % Tmax for Pyr entering Mitochondria
Tmax_W(33) = URR_W(33)/Diff_W(33);     % Tmax for FAC entering Mitochondria
Tmax_W(34) = URR_W(34)/Diff_W(34);     % Tmax for NADH/NAD entering Mitochondria
Tmax_W(35) = URR_W(35)/Diff_W(35);     % Tmax for NADH/NAD leaveing Mitochondria 
Tmax_W(36) = URR_W(36)/Diff_W(36);     % Tmax for ATP leaveing Mitochondria 
Tmax_W(37) = URR_W(37)/Diff_W(37);     % Tmax for ADP entering Mitochondria
Tmax_W(38) = URR_W(38)/Diff_W(38);     % Tmax for Pi entering Mitochondria
Tmax_W(39) = URR_W(39)/Diff_W(39);     % Tmax for CoA leaveing Mitochondria 
Tmax_W(40) = URR_W(40)/Diff_W(40);     % Tmax for H leaveing Mitochondria 

%******************************************************************************
% This section computes the Reaction parameters of the reaction fluxes
% based on enzyme kinetics. In each reaction, the general form is 
% Rflux = (Vmaxf[C_s]/Kf-Vmaxb[C_p]/Kb)/(1+C_s/Kf+C_p/Kb)
% then  each reaction include 4 parameters and the specific controllers
% the two Vmaxf and Vmaxb are determined by thermodynamic constraints
% 
% Note: Here we assume all Kf, Kb and Km are same in both fibers and the previous
% parameters are used directly. Because of the corresponding reaction fluxes
% changes, Vmaxf and Vmaxb have to be recalculated
%******************************************************************************
Kf    = zeros(31,1);                  % Forward reaction constant
Kb    = zeros(31,1);                  % Backward reaction constant
Km    = zeros(31,1);                  % MM constant defined in specific controllers 
nH    = zeros(31,1);                  % exponential coefficients of controllers

Vmaxf_R = zeros(31,1);                % Vmax of forward reaction
Vmaxb_R = zeros(31,1);                % Vmax of backward reaction 

Vmaxf_W = zeros(31,1);                % Vmax of forward reaction
Vmaxb_W = zeros(31,1);                % Vmax of backward reaction 

Kf(1:31)   = theta(213:243);
Kb(1:31)   = theta(244:274);
Km(1:31)   = theta(275:305);
nH(1:31)   = theta(306:336);


%--------------------------------------------------------------------------
% Calcuate Vmaxf and Vmaxb with the subroutine 
[Vmaxf_R, Vmaxb_R] =Sub_Parameter(Kf, Kb, Km, nH, Rflux_R, Cc_R);
[Vmaxf_W, Vmaxb_W] =Sub_Parameter(Kf, Kb, Km, nH, Rflux_W, Cc_W);
%**************************************************************************
%                    Write parameters to data file
%**************************************************************************
% %Type I
% Parameters_R = [Tmax_R;Mm_R;Lam_R;Vmaxf_R;Vmaxb_R;Kf;Kb;Km;nH];
% dlmwrite('InitialParameters_R.txt', Parameters_R ,'precision','%20.14d');
% 
% %Type II
% Parameters_W = [Tmax_W;Mm_W;Lam_W;Vmaxf_W;Vmaxb_W;Kf;Kb;Km;nH;];
% dlmwrite('InitialParameters_W.txt', Parameters_W ,'precision','%20.14d');
%==========================================================================
save Para_r Tmax_R Mm_R Lam_R Vmaxf_R Vmaxb_R Kf Kb Km nH
save para_w Tmax_W Mm_W Lam_W Vmaxf_W Vmaxb_W Kf Kb Km nH
%*************************************************************************
% Keq_0 = zeros(31,1);
% Keq_0 = dlmread('RestingKeq.txt');                        %Adjusted Keq 
R   = 8.314;
T   = 310.15;

Cc_R(34)/Cc_R(35)
Cc_W(34)/Cc_W(35)


% Cc_R(22)*Cc_R(24) - Cc_R(23)^2/Keq_0(17)

% -R*T*log((Cc_R(21)*Cc_R(22))/(Cc_R(20)*Cc_R(23)*Cc_R(29))/10^(0.1))/1000
% -R*T*log((Cc_W(21)*Cc_W(22))/(Cc_W(20)*Cc_W(23)*Cc_W(29))/10^(0.1))/1000
%  
%   -R*T*log(Cc_R(23)^2/(Cc_R(22)*Cc_R(24))/10^(0.1))/1000   
%   -R*T*log(Cc_W(23)^2/(Cc_W(22)*Cc_W(24))/10^(0.1))/1000


%******************************************************************************
% Calculation of total CO2 concentration in blood (pH in plasma and RBC is 
% assumed to be constant; equal to 7.4 plasma and 7.24 in RBC).
%******************************************************************************
function [SHbCO2,CHbCO2,CHCO3,CO2Tot] = CO2Tot_Blood(CO2)

Hct = 0.45;                     % Standard hematocrit
CHbrbc = 5.2;                   % Concentration of hemoglobin in RBC (mM)
CHbCO2Max = 4*Hct*CHbrbc;       % HbCO2 concentration in blood at 100% HbO2 saturation (mM)
pHpl = 7.4;                     % Standard pH in plasma
pHrbc = 7.24;                   % Standard pH in RBC
CHpl = 10^(-pHpl+3);            % H+ concentration in plasma (mM)
CHrbc = 10^(-pHrbc+3);          % H+ concentration in RBC (mM)
Rrbc = CHpl/CHrbc;              % Gibb-Donnan equilibrium constant
KeqCO2hyd = 7.94e-4;            % Equilibrium constant for CO2 hydration (mM)
alphaCO2 = 3.05e-2;             % Solubility of CO2 in blood (mM/mmHg)
P50HbCO2 = 265.0;               % PCO2 at 50% HbCO2 saturation (mmHg)
C50HbCO2 = alphaCO2*P50HbCO2;   % Free CO2 concentration at 50% HbCO2 saturation (mM)
KHbCO2 = 1/C50HbCO2;            % Hill constant for SHbCO2 (mM^-1)

SHbCO2 = KHbCO2*CO2/(1+KHbCO2*CO2); % HbCO2 saturation (unitless)
CHbCO2 = CHbCO2Max*SHbCO2;      % Hb-bound CO2 concentration (mM)
CHCO3pl = KeqCO2hyd*CO2/CHpl;   % Concentration of HCO3 (bicarbonate) in plasma (mM)
CHCO3rbc = Rrbc*CHCO3pl;        % Concentration of HCO3m in RBC (mM)
CHCO3 = (1-Hct)*CHCO3pl + Hct*CHCO3rbc; % Concentration of HCO3m (mM) in blood
CO2Tot = CO2 + CHbCO2 + CHCO3;  % Total CO2 concentration (mM) in blood

%******************************************************************************
% Calculation of total O2 concentration in blood (pH in plasma and RBC is 
% assumed to be constant; equal to 7.4 plasma and 7.24 in RBC).
%******************************************************************************

function [SHbO2,CHbO2,O2Tot] = O2Tot_Blood(O2)

Hct = 0.45;                     % Standard hematocrit
CHbrbc = 5.2;                   % Concentration of hemoglobin in RBC (mM)
CHbO2Max = 4*Hct*CHbrbc;        % HbO2 concentration at 100% HbO2 saturation (mM)
alphaO2 = 1.35e-3;              % Solubility of O2 in plasma (mM/mmHg)
P50HbO2 = 26.8;                 % PO2 at 50% HbO2 saturation (mmHg)
C50HbO2 = alphaO2*P50HbO2;      % Free O2 concentration at 50% HbO2 saturation (mM)
nH = 2.7;                       % Hill coefficient for SHbO2 (unitless)
KHbO2 = 1/C50HbO2^nH;           % Hill constant for SHbO2 (mM^-nH)

SHbO2 = KHbO2*O2^nH/(1+KHbO2*O2^nH);  % HbO2 saturation (unitless)
CHbO2 = CHbO2Max*SHbO2;         % Hb-bound O2 concentration in blood (mM)
O2Tot = O2 + CHbO2;             % Total O2 concentration in blood (mM) 

%******************************************************************************
% Calculation of free CO2 concentration from total CO2 concentration in blood 
% (pH in plasma and RBC is assumed to be constant; equal to 7.4 plasma and 
% 7.24 in RBC).
%******************************************************************************

function [SHbCO2,CHbCO2,CHCO3,CO2Tot] = CO2Tot_Blood(CO2)

Hct = 0.45;                     % Standard hematocrit
CHbrbc = 5.2;                   % Concentration of hemoglobin in RBC (mM)
CHbCO2Max = 4*Hct*CHbrbc;       % HbCO2 concentration in blood at 100% HbO2 saturation (mM)
pHpl = 7.4;                     % Standard pH in plasma
pHrbc = 7.24;                   % Standard pH in RBC
CHpl = 10^(-pHpl+3);            % H+ concentration in plasma (mM)
CHrbc = 10^(-pHrbc+3);          % H+ concentration in RBC (mM)
Rrbc = CHpl/CHrbc;              % Gibb-Donnan equilibrium constant
KeqCO2hyd = 7.94e-4;            % Equilibrium constant for CO2 hydration (mM)
alphaCO2 = 3.05e-2;             % Solubility of CO2 in blood (mM/mmHg)
P50HbCO2 = 265.0;               % PCO2 at 50% HbCO2 saturation (mmHg)
C50HbCO2 = alphaCO2*P50HbCO2;   % Free CO2 concentration at 50% HbCO2 saturation (mM)
KHbCO2 = 1/C50HbCO2;            % Hill constant for SHbCO2 (mM^-1)

SHbCO2 = KHbCO2*CO2/(1+KHbCO2*CO2); % HbCO2 saturation (unitless)
CHbCO2 = CHbCO2Max*SHbCO2;      % Hb-bound CO2 concentration (mM)
CHCO3pl = KeqCO2hyd*CO2/CHpl;   % Concentration of HCO3 (bicarbonate) in plasma (mM)
CHCO3rbc = Rrbc*CHCO3pl;        % Concentration of HCO3m in RBC (mM)
CHCO3 = (1-Hct)*CHCO3pl + Hct*CHCO3rbc; % Concentration of HCO3m (mM) in blood
CO2Tot = CO2 + CHbCO2 + CHCO3;  % Total CO2 concentration (mM) in blood


%******************************************************************************
% Calculation of total CO2 concentration in muscle cells (pH in cells is
% assumed to be constant; equal to 7.1).
%******************************************************************************

function [CHCO3,CO2Tot] = CO2Tot_Cells(CO2)

pH = 7.1;                       % standard pH in cells
CH = 10^(-pH+3);                % H+ concentration in cells (mM)
KeqCO2hyd = 7.94e-4;            % Equilibrium constant for CO2 hydration (mM)
alphaCO2 = 3.05e-2;             % Solubility of CO2 in cells (mM/mmHg)

CHCO3 = KeqCO2hyd*CO2/CH;       % Concentration of HCO3 (bicarbonate) in cells (mM)
CO2Tot = CO2 + CHCO3;           % Total CO2 concentration in cells (mM)

%******************************************************************************
% Calculation of total O2 concentration in blood (pH in plasma and RBC is 
% assumed to be constant; equal to 7.4 plasma and 7.24 in RBC).
%******************************************************************************

function [SHbO2,CHbO2,O2Tot] = O2Tot_Blood(O2)

Hct = 0.45;                     % Standard hematocrit (unitless)
CHbrbc = 5.2;                   % Concentration of hemoglobin in RBC (mM)
CHbO2Max = 4*Hct*CHbrbc;        % HbO2 concentration at 100% HbO2 saturation (mM)
alphaO2 = 1.35e-3;              % Solubility of O2 in plasma (mM/mmHg)
P50HbO2 = 26.8;                 % PO2 at 50% HbO2 saturation (mmHg)
C50HbO2 = alphaO2*P50HbO2;      % Free O2 concentration at 50% HbO2 saturation (mM)
nH = 2.7;                       % Hill coefficient for SHbO2 (unitless)
KHbO2 = 1/C50HbO2^nH;           % Hill constant for SHbO2 (mM^-nH)

SHbO2 = KHbO2*O2^nH/(1+KHbO2*O2^nH);  % HbO2 saturation (unitless)
CHbO2 = CHbO2Max*SHbO2;         % Hb-bound O2 concentration in blood (mM)
O2Tot = O2 + CHbO2;             % Total O2 concentration in blood (mM) 

%**************************************************************************
% Calculation of total O2 concentration in muscle cells.
%**************************************************************************

function [SMbO2,CMbO2,O2Tot] = O2Tot_Cells(O2)

CMb = 0.5;                        % Concentration of myoglobin in cells (mM)
alphaO2 = 1.35e-3;              % Solubility of O2 in cells (mM/mmHg)
P50MbO2 = 2.4;                  % PO2 at 50% MbO2 saturation (mmHg)
C50MbO2 = alphaO2*P50MbO2;      % Free O2 concentration at 50% MbO2 saturation (mM)
KMbO2 = 1/C50MbO2;              % Hill constant for SMbO2 (mM^-1)

SMbO2 = KMbO2*O2/(1+KMbO2*O2);  % MbO2 saturation in tissue cells
CMbO2 = CMb*SMbO2;              % Mb-bound O2 concentration in cells (mM)
O2Tot = O2 + CMbO2;             % Total O2 concentration in cells (mM) 

%******************************************************************************
% Calculation of free CO2 concentration from total CO2 concentration in blood 
% (pH in plasma and RBC is assumed to be constant; equal to 7.4 plasma and 
% 7.24 in RBC).
%******************************************************************************

function [CO2,SHbCO2,CHbCO2,CHCO3] = CO2_Blood(CO2Tot)

Hct = 0.45;                     % Standard hematocrit
CHbrbc = 5.2;                   % Concentration of hemoglobin in RBC (mM)
CHbCO2Max = 4*Hct*CHbrbc;       % HbCO2 concentration at 100% HbCO2 saturation
pHpl = 7.4;                     % standard pH in plasma
pHrbc = 7.24;                   % standard pH in plasma
CHpl = 10^(-pHpl+3);            % H+ concentration in plasma (mM)
CHrbc = 10^(-pHrbc+3);          % H+ concentration in RBC (mM)
Rrbc = CHpl/CHrbc;              % Gibb-Donnan equilibrium constant for RBC
KeqCO2hyd = 7.94e-4;            % Equilibrium constant for CO2 hydration (mM)
alphaCO2 = 3.05e-2;             % Solubility of CO2 in blood (mM/mmHg)
P50HbCO2 = 265.0;               % PCO2 at 50% HbCO2 saturation (mmHg)
C50HbCO2 = alphaCO2*P50HbCO2;   % Free CO2 concentration at 50% HbCO2 saturation (mM)
KHbCO2 = 1/C50HbCO2;            % Hill constant for SHbCO2 (mM^-nH)

iter_max = 10;                  % Maximum number of allowed iterations
iter_tol = 1e-4;                % Tolerance for convergence
CO2_old = alphaCO2*40;          % Initial guess for PCO2 in cells is 40 mmHg
error = 1.0;                    % Initial error, an arbitraty large number
iter = 0;

% Newton-Raphson's iterative method...
while (iter < iter_max & error > iter_tol)
    SHbCO2_old = KHbCO2*CO2_old/(1+KHbCO2*CO2_old);
    CHbCO2_old = CHbCO2Max*SHbCO2_old;
    CHCO3pl_old = KeqCO2hyd*CO2_old/CHpl;
    CHCO3rbc_old = Rrbc*CHCO3pl_old;
    CHCO3_old = (1-Hct)*CHCO3pl_old + Hct*CHCO3rbc_old;
    DSHbCO2_old = KHbCO2/(1+KHbCO2*CO2_old)^2;
    DCHbCO2_old = CHbCO2Max*DSHbCO2_old;
    DCHCO3pl_old = KeqCO2hyd/CHpl;
    DCHCO3rbc_old = Rrbc*DCHCO3pl_old;
    DCHCO3_old = (1-Hct)*DCHCO3pl_old + Hct*DCHCO3rbc_old;
    funcCO2 = CO2Tot - (CO2_old + CHbCO2_old + CHCO3_old);
    DfuncCO2 = - (1 + DCHbCO2_old + DCHCO3_old);
    CO2_new = CO2_old - funcCO2/DfuncCO2;
    iter = iter + 1;
    error = abs(CO2_new - CO2_old)/CO2_new;
    CO2_old = CO2_new;
end

% Fixed point iteration method...
%while (iter < iter_max & error > iter_tol)
%    SHbCO2_old = KHbCO2*CO2_old/(1+KHbCO2*CO2_old);
%    CHbCO2_old = CHbCO2Max*SHbCO2_old;
%    CHCO3_new = (CO2Tot - CO2_old - CHbCO2_old);
%    CHCO3pl_new = CHCO3_new/((1-Hct) + Hct*Rrbc);
%    CO2_new = CHCO3pl_new*CHpl/KeqCO2hyd;
%    iter = iter + 1;
%    error = abs(CO2_new - CO2_old)/CO2_new;
%    CO2_old = CO2_new;
%end

% Calculate the free, Hb-bound CO2, and bicarbonate CO2 concentrations...
CO2 = CO2_old;                           % Free CO2 concentration (mM)
SHbCO2 = KHbCO2*CO2/(1+KHbCO2*CO2);      % HbCO2 saturation (unitless)
CHbCO2 = CHbCO2Max*SHbCO2;               % Hb-bound CO2 concentration (mM)
CHCO3pl = KeqCO2hyd*CO2/CHpl;            % Concentration of HCO3 in plasma (mM)
CHCO3rbc = Rrbc*CHCO3pl;                 % Concentration of HCO3m in RBC (mM)
CHCO3 = (1-Hct)*CHCO3pl + Hct*CHCO3rbc;  % Concentration of HCO3m (mM) in blood

%******************************************************************************
% Calculation of free O2 concentration from total O2 concentration in blood 
% (pH in plasma and RBC is assumed to be constant; equal to 7.4 plasma and 
% 7.24 in RBC).
%******************************************************************************

function [O2,SHbO2,CHbO2] = O2_Blood(O2Tot)

Hct = 0.45;                     % Standard hematocrit
CHbrbc = 5.2;                   % Concentration of hemoglobin in RBC (mM)
CHbO2Max = 4*Hct*CHbrbc;        % HbO2 concentration at 100% HbO2 saturation (mM)
alphaO2 = 1.35e-3;              % Solubility of O2 in blood (mM/mmHg)
P50HbO2 = 26.8;                 % PO2 at 50% HbO2 saturation (mmHg)
C50HbO2 = alphaO2*P50HbO2;      % Free O2 concentration at 50% HbO2 saturation (mM)
nH = 2.7;                       % Hill coefficient for SHbO2
KHbO2 = 1/C50HbO2^nH;           % Hill constant for SHbO2 (mM^-nH)

iter_max = 10;                  % Maximum number of allowed iterations
iter_tol = 1e-4;                % Tolerance for convergence
O2_old = alphaO2*50;            % Initial guess for PO2 in cells is 50 mmHg
error = 1.0;                    % Initial error, an arbitraty large number
iter = 0;

% Newton-Raphson's iterative method...
while (iter < iter_max & error > iter_tol)
    SHbO2_old = KHbO2*O2_old^nH/(1+KHbO2*O2_old^nH);
    CHbO2_old = CHbO2Max*SHbO2_old;
    DSHbO2_old = nH*KHbO2*O2_old^(nH-1)/(1+KHbO2*O2_old^nH)^2;
    DCHbO2_old = CHbO2Max*DSHbO2_old;
    funcO2 = O2Tot - (O2_old + CHbO2_old);
    DfuncO2 = - (1 + DCHbO2_old);
    O2_new = O2_old - funcO2/DfuncO2;
    iter = iter + 1;
    error = abs(O2_new - O2_old)/O2_new;
    O2_old = O2_new;
end

% Fixed point iteration method...
%while (iter < iter_max & error > iter_tol)
%    SHbO2_new = (O2Tot-O2_old)/CHbO2Max;
%    O2_new = (SHbO2_new/(KHbO2*(1-SHbO2_new)))^(1/nH);
%   iter = iter + 1;
%    error = abs(O2_new - O2_old)/O2_new;
%    O2_old = O2_new;
%end

% Calculate the free and Hb-bound O2 concentrations in blood...
O2 = O2_old;                            % Free O2 concentration (mM)
SHbO2 = KHbO2*O2^nH/(1+KHbO2*O2^nH);    % HbO2 saturation (unitless)
CHbO2 = CHbO2Max*SHbO2;                 % Hb-bound O2 concentration (mM)
%******************************************************************************
%******************************END*****************************************


