function [URR]=Sub_B_Transport(Cb, Cc, Tmax, Mm, Lam, Activ_t)
%******************************************************************************
% This subroutine is to calculate the transport rate between blood and cytosol and
% between cytosol and mitochondria.

% Modified on Jun. 6, 2009
%******************************************************************************
UPT =zeros(50,1);
REL =zeros(50,1);
URR =zeros(50,1);

%*****************************************************************************
%                     Transport between Blood and Cytosol 
%*****************************************************************************

UPT(1) = Tmax(1)*Cb(1)/(Mm(1) + Cb(1));                     % Uptake of GLU from blood
UPT(1) = Activ_t(1) * UPT(1);
REL(1) = Tmax(1)*Cc(1)/(Mm(1) + Cc(1));                     % Release of GLU to blood
REL(1) = Activ_t(1) * REL(1);

UPT(2) = Tmax(2)*Cb(2)/(Mm(2) + Cb(2));                     % Uptake of Pyr from blood
UPT(2) = Activ_t(2) * UPT(2);
REL(2) = Tmax(2)*Cc(2)/(Mm(2) + Cc(2));                     % Release of Pyr to blood
REL(2) = Activ_t(2) * REL(2);

UPT(3) = Tmax(3)*Cb(3)/(Mm(3) + Cb(3));                     % Uptake of LAC from blood
UPT(3) = Activ_t(3) * UPT(3);
REL(3) = Tmax(3)*Cc(3)/(Mm(3) + Cc(3));                     % Release of LAC to blood
REL(3) = Activ_t(3) * REL(3);

UPT(6) = Tmax(6)*Cb(6)/(Mm(6) + Cb(6));                     % Uptake of FFA from blood
UPT(6) = Activ_t(6) * UPT(6);
REL(6) = Tmax(6)*Cc(6)/(Mm(6) + Cc(6));                     % Release of FFA to blood
REL(6) = Activ_t(6) * REL(6);

UPT(4) = Lam(4)*Cb(4);                                      % Uptake of ALA from blood
UPT(4) = Activ_t(4) * UPT(4);
REL(4) = Lam(4)*Cc(4);                                      % Release of ALA to blood
REL(4) = Activ_t(4) * REL(4);

UPT(5) = Lam(5)*Cb(5);                                      % Uptake of GLR from blood
UPT(5) = Activ_t(5) * UPT(5);
REL(5) = Lam(5)*Cc(5);                                      % Release of GLR to blood
REL(5) = Activ_t(5) * REL(5);

UPT(7) = Lam(7)*Cb(7);                                      % Uptake of CO2 from blood
UPT(7) = Activ_t(7) * UPT(7);
REL(7) = Lam(7)*Cc(7);                                      % Release of CO2 to blood
REL(7) = Activ_t(7) * REL(7);

UPT(8) = Lam(8)*Cb(8);                                      % Uptake of O2 from blood
UPT(8) = Activ_t(8) * UPT(8);
REL(8) = Lam(8)*Cc(8);                                      % Release of O2 to blood
REL(8) = Activ_t(8) * REL(8);

UPT(29) = Tmax(29)*Cb(9)/(Mm(29)+Cb(9));                  % Uptake of H from blood
UPT(29) = Activ_t(29) * UPT(29);
REL(29) = Tmax(29)*Cc(29)/(Mm(29)+Cc(29));                  % Release of H to blood
REL(29) = Activ_t(29) * REL(29);

%*****************************************************************************
%                 Transport between Cytosol and Mitochondria 
%*****************************************************************************
UPT(30) = Lam(30)*Cc(8);                                    % Uptake of O2 from Cytosol
UPT(30) = Activ_t(30) * UPT(30);
UPT(31) = Lam(31)*Cc(7);                                    % Uptake of CO2 from Cytosol
UPT(31) = Activ_t(31) * UPT(31);

REL(30) = Lam(30)*Cc(30);                                   % Release of O2 to Cytosol
REL(30) = Activ_t(30) * REL(30);
REL(31) = Lam(31)*Cc(31);                                   % Release of CO2 to Cytosol
REL(31) = Activ_t(31) * REL(31);

UPT(32) = Tmax(32)*Cc(2) /(Mm(32)+Cc(2));                   % Uptake of Pyr from Cytosol
UPT(33) = Tmax(33)*  Cc(19)/(Mm(33)+Cc(19));                % Uptake of FAC from Cytosol
UPT(34) = Tmax(34)*(Cc(27)/Cc(28))/(Mm(34)+ Cc(27)/Cc(28)); % Uptake of NADH from Cytosol
UPT(35) = -UPT(34);                                                            % Uptake of NAD from Cytosol
UPT(36)=  Tmax(36)*(Cc(22)/Cc(23))/(Mm(36)+ Cc(22)/Cc(23)); %ATP/ADP
UPT(37) = -UPT(36);
UPT(38) = Tmax(38)*Cc(25)/(Mm(38)+Cc(25));                  % Uptake of Pi from Cytosol
UPT(39) = Tmax(39)*Cc(26)/(Mm(39)+Cc(26));                  % Uptake of CoA from Cytosol
UPT(40) = Tmax(40)*Cc(29)/(Mm(40)+Cc(29));                  % Uptake of H from Cytosol
%------------
UPT(32:40) = Activ_t(32:40).*UPT(32:40);                    % Activated Uptake 

%++++++++++++++++++
REL(32) = Tmax(32)*Cc(32)/(Mm(32)+Cc(32));                  % Release of Pyr to Cytosol
REL(33) = Tmax(33) * Cc(33)/(Mm(33)+Cc(33));                % Release of FAC to Cytosol
REL(34) = Tmax(34)*(Cc(34)/Cc(35))/(Mm(35)+ Cc(34)/Cc(35)); % Release of NADH to Cytosol
REL(35) = -REL(34);                                         % Release of NAD to Cytosol
REL(36) =  Tmax(36)*(Cc(36)/Cc(37))/(Mm(37)+ Cc(36)/Cc(37));%ATP/ADP
REL(37) = -REL(36);                          % 
REL(38) = Tmax(38)*Cc(38)/(Mm(38)+Cc(38));                  % Release of Pi to Cytosol
REL(39) = Tmax(39)*Cc(39)/(Mm(39)+Cc(39));                  % Release of CoA to Cytosol
REL(40) = Tmax(40)*Cc(40)/(Mm(40)+Cc(40));                  % Release of H to Cytosol

%------------
REL(32:40) = Activ_t(32:40).*REL(32:40);                    % Activated Release 

URR(:) = UPT(:) - REL(:);        
%******************************************************************************
%                  END OF THE FUNCTION
%******************************************************************************
