function [Rflux]= Sub_C_Reaction(Cc, Vmaxf, Vmaxb, Kf, Kb, Km, nH,Activ_r)
%******************************************************************************
% This subroutine is to calculate the reaction flux rates in tissue
% 
% Modified on Jun. 6, 2009
%******************************************************************************
Ctrl  = ones(31,1);                                 % Reaction controller associated with indirect effect
Rflux = zeros(31,1);
%--------------------------------------------------------------------------
F   = 96485;                                        % Faraday 's constant [coulomb/mole]
nA  = 3;                                            % 3 protons for 1 ATP 
R   = 8.314;                                        % Constant 
Tem = 310.15;                                       % Absolute temperature of body 
DeltaGH = F*Cc(50)+ R*Tem*log(Cc(29)/Cc(40));       % Proton motive energy
% Note: Above constants and variable are used in the calcuation of special
% terms in the three reactions of Oxidative phosphorylation
%__________________________________________________________________________
% Hexokinase:                 Glc + ATP-> G6P+ADP +H
Ctrl(1) = Km(1)^nH(1)/(Km(1)^nH(1) + Cc(9)^nH(1));
Rflux(1) =Activ_r(1)*Ctrl(1)*...
          (Vmaxf(1)*Cc(1)*Cc(22)/Kf(1) - Vmaxb(1)*Cc(9)*Cc(23)*Cc(29)/Kb(1))...
          /(1+Cc(1)*Cc(22)/Kf(1)+ Cc(9)*Cc(23)*Cc(29)/Kb(1)); 
% Phosphoglucomutase:         G1P<---> G6P 
Rflux(2) = 0;

% UDP-glucose pyrophosphorylase +glycogen synthase:  G6P + ATP + Gly_n + H2O-> Gly_n+1 + ADP+ 2Pi
Rflux(3) = Activ_r(3)*...
          (Vmaxf(3)*Cc(9)*Cc(22)*Cc(11)/Kf(3) - Vmaxb(3)*Cc(11)*Cc(23)*Cc(25)^2/Kb(3))/...
          (1 + Cc(9)*Cc(22)*Cc(11)/Kf(3)+ Cc(11)*Cc(23)*Cc(25)^2/Kb(3));
%Glycogen phosphorylase:      Gly(n+1)+Pi->Gly(n)+ G6P
Ctrl(4) = (Cc(24)/Cc(22))^nH(4)/(Km(4)^nH(4) + (Cc(24)/Cc(22))^nH(4)); 
Rflux(4) = Activ_r(4)*Ctrl(4)*...
           (Vmaxf(4)*Cc(11)*Cc(25)/Kf(4) - Vmaxb(4)*Cc(11)*Cc(9)/Kb(4))...
           /(1 + Cc(11)*Cc(25)/Kf(4) + Cc(11)*Cc(9)/Kb(4)); 
% Phosphoglucose isomerase:   G6P->F6P
Rflux(5) = Activ_r(5)*...
           (Vmaxf(5)*Cc(9)/Kf(5) - Vmaxb(5)*Cc(12)/Kb(5))...
           /(1 + Cc(9)/Kf(5) + Cc(12)/Kb(5));
 
% Phosphofructokinase:        F6P+ATP->F16BP+ADP+H
Ctrl(6) = (Cc(24))^nH(6)/(Km(6)^nH(6) + (Cc(24))^nH(6));
Rflux(6) =Activ_r(6)* Ctrl(6)*...
         (Vmaxf(6)*Cc(12)*Cc(22)/Kf(6) - Vmaxb(6)*Cc(13)*Cc(23)*Cc(29)/Kb(6))...
         /(1+ Cc(12)*Cc(22)/Kf(6) + Cc(13)*Cc(23)*Cc(29)/Kb(6));

% Aldolase +Triose phosphate isomerase      F16BP<--->2GA3P
Rflux(7) = Activ_r(7)*...
           (Vmaxf(7)*Cc(13)/Kf(7) - Vmaxb(7)*Cc(14)^2/Kb(7))...
           /(1+Cc(13)/Kf(7) + Cc(14)^2/Kb(7)); 

% Glyceraldehyde 3-phosphate dehydrogenase: GA3P+Pi+NAD->13BPG+NADH + H
Rflux(8) =Activ_r(8)* ...
          (Vmaxf(8)*Cc(14)*Cc(25)*Cc(28)/Kf(8) - Vmaxb(8)*Cc(15)*Cc(27)*Cc(29)/Kb(8))...
          /(1+Cc(14)*Cc(25)*Cc(28)/Kf(8)+Cc(15)*Cc(27)*Cc(29)/Kb(8));

% Phosphoglycerate kinase:     13BPG +ADP-> PEP +ATP +H2O
Rflux(9) =Activ_r(9)* ...
          (Vmaxf(9)*Cc(15)*Cc(23)/Kf(9) - Vmaxb(9)*Cc(16)*Cc(22)/Kb(9))...
          /(1+Cc(15)*Cc(23)/Kf(9) + Cc(16)*Cc(22)/Kb(9));

% Pyruvate kinase:              PEP + ADP + H<--->Pyr +ATP
Ctrl(10) = Cc(13)^nH(10)/(Km(10)^nH(10) + Cc(13)^nH(10));
Rflux(10)= Activ_r(10)*Ctrl(10)*...
           (Vmaxf(10)*Cc(16)*Cc(23)*Cc(29)/Kf(10) - Vmaxb(10)*Cc(2)*Cc(22)/Kb(10))...
           /(1+Cc(16)*Cc(23)*Cc(29)/Kf(10) + Cc(2)*Cc(22)/Kb(10));         

% Lactate dehydrogenase:        Pyr+NADH+H -> Lac+NAD
Rflux(11) = Activ_r(11)*...
            (Vmaxf(11)*Cc(2)*Cc(27)*Cc(29)/Kf(11) - Vmaxb(11)*Cc(3)*Cc(28)/Kb(11))...
            /(1+Cc(2)*Cc(27)*Cc(29)/Kf(11) + Cc(3)*Cc(28)/Kb(11));          
 
%-----------------------------
% Fluxes in Lipid Metabolism
% Lipases:                      TGl -> 3FFA + Glr + 3H 
Rflux(12) =Activ_r(12)* ...
          (Vmaxf(12)*Cc(17)/Kf(12) - Vmaxb(12)*Cc(5)* Cc(6)^3*Cc(29)^3/Kb(12))...
          /(1+ Cc(17)/Kf(12) + Cc(5)* Cc(6)^3*Cc(29)^3/Kb(12));

% Glycerol 3-phosphate dehydrogenase:  GA3P + NADH + H-> Gr3P+NAD
Rflux(13) =Activ_r(13)* ...
          (Vmaxf(13)*Cc(14)*Cc(27)*Cc(29)/Kf(13) - Vmaxb(13)*Cc(18)*Cc(28)...
          /Kb(13))/(1 + Cc(14)*Cc(27)*Cc(29)/Kf(13) + Cc(18)*Cc(28)/Kb(13));

% Acyltransferase:              G3P+3FAC->Tgl+3CoA +Pi
Rflux(14) =Activ_r(14)* ...
           (Vmaxf(14)*Cc(18)*Cc(19)^3/Kf(14) - Vmaxb(14)*Cc(17)* Cc(26)^3 *Cc(25)/Kb(14))...
           /(1+Cc(18)*Cc(19)^3/Kf(14) + Cc(17)* Cc(26)^3 *Cc(25)/Kb(14)); 
 
% Acyl-CoA synthetase:          FFA +CoA +2ATP ->FAC+2ADP+2Pi+2H
Rflux(15) = Activ_r(15)*...
           (Vmaxf(15)*Cc(6)*Cc(26)*Cc(22)^2/Kf(15) - Vmaxb(15)*Cc(19)*Cc(23)^2*Cc(25)^2*Cc(29)^2/Kb(15))/...
           (1+Cc(6)*Cc(26)*Cc(22)^2/Kf(15) + Cc(19)*Cc(23)^2*Cc(25)^2*Cc(29)^2/Kb(15));    

% Fluxes of Energetics:
% ATPase:                       ATP -> ADP + Pi + H+
Rflux(16) = Activ_r(16)*...
            (Vmaxf(16)*Cc(22)/Kf(16) - Vmaxb(16)*Cc(23)*Cc(25)*Cc(29)/Kb(16))/(1 + Cc(22)/Kf(16) + Cc(23)*Cc(25)*Cc(29)/Kb(16)); 

% Adenylate kinase:             ATP + AMP<-> 2ADP
Rflux(17) = Activ_r(17)*...
           (Vmaxf(17)*Cc(22)*Cc(24)/Kf(17) - Vmaxb(17)*Cc(23)^2/Kb(17))/(1 + Cc(22)*Cc(24)/Kf(17) + Cc(23)^2/Kb(17));

% Creatine kinase:              PCr + ADP + H <-> Cr+ATP
Rflux(18) =Activ_r(18)* ...
           (Vmaxf(18)*Cc(20)*Cc(23)*Cc(29)/Kf(18) - Vmaxb(18)*Cc(21)*Cc(22)/Kb(18))...
            /(1 + Cc(20)*Cc(23)*Cc(29)/Kf(18)+ Cc(21)*Cc(22)/Kb(18));

% Fluxes in Amino Acid Metabolism
% Alanine aminotransferase:       Pyr+Glu-> Ala +AKG
Rflux(19) = Activ_r(19)*...
            (Vmaxf(19)*Cc(2)/Kf(19) - Vmaxb(19)*Cc(4)/Kb(19))/(1+Cc(2)/Kf(19) + Cc(4)/Kb(19));

%--------------------------------------------------------------------------
% Fluxes in Mitochondria
%--------------------------------------------------------------------------
% Fluxes into TCA Cycle
% Pyruvate dehydrogenase:         Pyr +H2O+CoA+NAD<--->NADH + ACoA +CO2 +H
Ctrl(20) = (Cc(37)/Cc(36))^nH(20)/(Km(20)^nH(20) + (Cc(37)/Cc(36))^nH(20));
Rflux(20)= Activ_r(20)*Ctrl(20)*...
            (Vmaxf(20)*Cc(32)*Cc(39)*Cc(35)/Kf(20) - Vmaxb(20)*Cc(34)*Cc(41)*Cc(31)*Cc(40)/Kb(20))/...
            (1+ Cc(32)*Cc(39)*Cc(35)/Kf(20) + Cc(34)*Cc(41)*Cc(31)*Cc(40)/Kb(20));

% Fatty acyl-CoA oxidation:       FAC + 7CoA + 7NAD+7FAD -> 8ACoA + 7NADH + 7FADH2 + 7H
 Rflux(21) = Activ_r(21)*...
            (Vmaxf(21)*Cc(33)*Cc(39)* Cc(35)*Cc(49)/Kf(21) - Vmaxb(21)*Cc(41)* Cc(34)*Cc(48)*Cc(40)/Kb(21))/...
            (1+Cc(33)*Cc(39)* Cc(35)* Cc(49)/Kf(21) + Cc(41)*Cc(34)*Cc(48)*Cc(40)/Kb(21));

%------------------------------------------------------------
% Fluxes in TCA Cycle
% Citrate synthase:               ACoA + Oxa-> Cit +CoA + H
Ctrl(22) = (Cc(37)/Cc(36))^nH(22)/(Km(22)^nH(22) + (Cc(37)/Cc(36))^nH(22));
Rflux(22) =Activ_r(22)*Ctrl(22)*...
          (Vmaxf(22)*Cc(41)*Cc(47)/Kf(22) - Vmaxb(22)*Cc(42)*Cc(39)*Cc(40)/Kb(22))/(1 + Cc(41)*Cc(47)/Kf(22) + Cc(42)*Cc(39)*Cc(40)/Kb(22));

% Isocitrate dehydrogenase:       Cit + NAD+H2O-> AKG +NADH + CO2
Ctrl(23) = (Cc(37)/Cc(36))^nH(23)/(Km(23)^nH(23)+ (Cc(37)/Cc(36))^nH(23));
Rflux(23) =Activ_r(23)* ...
           Ctrl(23)*(Vmaxf(23)*Cc(42)*Cc(35)/Kf(23) - Vmaxb(23)*Cc(43)*Cc(34)*Cc(31)/Kb(23))/(1+Cc(42)*Cc(35)/Kf(23)+ Cc(43)*Cc(34)*Cc(31)/Kb(23));

% a-Ketoglutarate dehydrogenase:  AKG + CoA + NAD -> SCoA + NADH + CO2
Rflux(24) = Activ_r(24)*...
          (Vmaxf(24)*Cc(43)*Cc(39)*Cc(35)/Kf(24) - Vmaxb(24)*Cc(44)*Cc(34)*Cc(31)/Kb(24))...
          /(1+Cc(43)*Cc(39)*Cc(35)/Kf(24) + Cc(44)*Cc(34)*Cc(31)/Kb(24));

% Succinyl-CoA synthetase:        SCoA + ADP +Pi -> Suc +CoA +ATP+CO2
Rflux(25) = Activ_r(25)*...
           (Vmaxf(25)*Cc(44)*Cc(37)*Cc(38)/Kf(25) - Vmaxb(25)*Cc(45)*Cc(39)*Cc(36)/Kb(25))/...
           (1+ Cc(44)*Cc(37)*Cc(38)/Kf(25) + Cc(45)*Cc(39)*Cc(36)/Kb(25));        

% Succinate dehydrogenase:        Succ +FAD+H2O -> Mal +FADH2
Rflux(26) = Activ_r(26)*...
            (Vmaxf(26)*Cc(45)*Cc(49)/Kf(26) - Vmaxb(26)*Cc(46)*Cc(48)/Kb(26))...
             /(1+Cc(45)*Cc(49)/Kf(26) + Cc(46)*Cc(48)/Kb(26));

% Malate dehydrogenase:           Mal + NAD-> Oxa +NADH + H+
Rflux(27) = Activ_r(27)*...
            (Vmaxf(27)*Cc(46)*Cc(35)/Kf(27) - Vmaxb(27)*Cc(47)*Cc(34)*Cc(40)/Kb(27))...
            /(1+Cc(46)*Cc(35)/Kf(27) + Cc(47)*Cc(34)*Cc(40)/Kb(27));

%--------------------------------------------------------------------------
% 8. Fluxes in Oxidative Phosphorylation
% Complex 1:                      NADH + H +0.5O2->NAD + H2O
Ctrl(28)=exp((-10*DeltaGH/(R*Tem)));
Rflux(28) = Activ_r(28)*(Ctrl(28)...
          *Vmaxf(28)*Cc(34)*Cc(30)^0.5*Cc(40)/Kf(28) - Vmaxb(28)*Cc(35)/Kb(28))...
           /(1 + Cc(34)*Cc(30)^0.5*Cc(40)/Kf(28) + Cc(35)/Kb(28));

% Complex 2:                      FADH2+ 0.5O2->FAD + H2O 
Ctrl(29)=exp((-6*DeltaGH/(R*Tem)));
Rflux(29) = Activ_r(29)*(Ctrl(29)*...
          Vmaxf(29)*Cc(48)*Cc(30)^0.5/Kf(29) - Vmaxb(29)*Cc(49)/Kb(29))...
          /(1 + Cc(48)*Cc(30)^0.5/Kf(29) + Cc(49)/Kb(29));

% ATP Synthase:            H + ADP + Pi+ 3delataH ->ATP
%--------
Ctrl(30)= exp((nA*DeltaGH)/(R*Tem));
Rflux(30) = Activ_r(30)*(Ctrl(30)*...
            Vmaxf(30)*Cc(37)*Cc(38)*Cc(40)/Kf(30) - Vmaxb(30)*Cc(36)/Kb(30))...
            /(1 + Cc(37)*Cc(38)*Cc(40)/Kf(30) + Cc(36)/Kb(30));

% H Leakage:               H_im<>H_m
Rflux(31) = Activ_r(31)* Vmaxf(31)*Cc(29)/Cc(40);
%**************************************************************************
%                             End of subroutine 
%**************************************************************************

