% This code is to set the species concentration in fiber based on the
% different fiber composition
% Apr 14, 2011

function Sub_SkeletalMuscle_TissueSpeciesConcentration
format long e  
clear all
close all
clc
%**************************************************************************
% This section sets the volume ratio under each condition 
%--------------------------------------------------------------------------

V_R     = 0.4;        % Volume in Type I muscle 
V_W     = 0.4;         % Volume in Type II 
VR_cyt = 0.352;      % Cytosol volume in Type I muscle 
VR_mit = 0.048;      % Mitochondria volume in Type I muscle 
VW_cyt = 0.368;       % Cytosol muscle volume in Type II 
VW_mit = 0.032;       % Mitochondria muscle volume in Type II 
%**************************************************************************
% This section sets the concentration for whole tissue 
%--------------------------------------------------------------------------
C_tis =zeros( 37,1);                    
omega = zeros(37,1);                 % Mass distribution ratio between two fibers
lambda_R= zeros (37,1);             % Mass distribution ratio between cyt and mitochondria in Type I 
lambda_W= zeros (37,1);             % Mass distribution ratio between cyt and mitochondria in type II

C_tis(1) = 0.5;                      % Glucose    
C_tis(2) = 0.05;                      % Pyruvate
C_tis(3) = 0.78;                      % Lactate 
C_tis(4) = 1.3;                      % Alanine 
C_tis(5) = 0.065;                      % Glycerol
C_tis(6) = 0.4;                      % FFA 
C_tis(7) = 0;                      % CO2 
C_tis(8) = 0;                      % O2 
C_tis(9) = 0.25;                      % G6P
C_tis(10) = 95;                      % Glycogen
C_tis(11) = 0.044;                      % F6P
C_tis(12) = 0.06;                      % F16BP
C_tis(13) = 0.08;                      % GA3P
C_tis(14) = 0.08;                    % 13BPG
C_tis(15) = 0.0049;                   % PEP
C_tis(16) = 15;                      % Tglyceride 
C_tis(17) = 0.15;                      % Gr3P
C_tis(18) = 0.0035;                      % FAC
C_tis(19) = 20;                      % PCr
C_tis(20) = 10.5;                      % Cr
C_tis(21) = 6.2;                      % ATP
C_tis(22) = 0.8;                      % ADP
C_tis(23) = 0.04;                      % AMP
C_tis(24) = 2.75;                      % Pi
C_tis(25) = 0.02;                      % CoA
C_tis(26) = 0.05;                      % NADH
C_tis(27) = 0.45;                      % NAD
C_tis(28) = 0.002;                      % ACOA
C_tis(29) = 0.095;                      % Cit
C_tis(30) = 0.013;                      % AKG
C_tis(31) = 0.13;                      % SCoA
C_tis(32) = 0.095;                      % Suc
C_tis(33) = 0.095;                      % Mal
C_tis(34) = 0.0024;                      % Oaa
C_tis(35) = 0.024;                      % FADHA
C_tis(36) = 0.212;                      % FAD
C_tis(37) = 0;                          % H
%-------------------------------------------------------------------------\
omega(:) = 0.5;                      % for most of species, we assume they are evenly distributed;
omega(4) = 0.4;                      % Alanine 
omega(9) = 0.4;                      % G6P
omega(10) = 0.4;                     % Glycogen 
omega(16) = 0.7;                     % Triglyceride 
omega(19) = 0.45;                    % PCr
omega(20) = 0.42;                    % Cr
omega(21) = 0.45;                    % ATP
omega(22) = 0.7;                     % ADP
omega(23) = 0.3622090538;            % AMP
omega(26) = 0.6;                     % NADH
omega(27) = 0.6;                     % NAD
%-------------------------------------------------------------------------\
lambda_R(1) = 1;                      % Glucose    
lambda_R(2) = 0.95;                      % Pyruvate
lambda_R(3) = 1;                      % Lactate 
lambda_R(4) = 1;                      % Alanine 
lambda_R(5) = 1;                      % Glycerol
lambda_R(6) = 1;                      % FFA 
lambda_R(7) = 0;                      % CO2 
lambda_R(8) = 0;                      % O2 
lambda_R(9) = 1;                      % G6P
lambda_R(10) = 1;                      % Glycogen
lambda_R(11) = 1;                      % F6P
lambda_R(12) = 1;                      % F16BP
lambda_R(13) = 1;                      % GA3P
lambda_R(14) = 1;                      % 13BPG
lambda_R(15) = 1;                      % PEP
lambda_R(16) = 1;                      % Tglyceride 
lambda_R(17) = 1;                      % Gr3P
lambda_R(18) = 0.95;                      % FAC
lambda_R(19) = 1;                      % PCr
lambda_R(20) = 1;                      % Cr
lambda_R(21) = 0.848;                      % ATP
lambda_R(22) = 0.11;                      % ADP
lambda_R(23) = 1;                      % AMP
lambda_R(24) = 0.95;                      % Pi
lambda_R(25) = 0.8;                      % CoA
lambda_R(26) = 0.005;                      % NADH
lambda_R(27) = 0.3;                      % NAD
lambda_R(28) = 0;                      % ACOA
lambda_R(29) = 0;                      % Cit
lambda_R(30) = 0;                      % AKG
lambda_R(31) = 0;                      % SCoA
lambda_R(32) = 0;                      % Suc
lambda_R(33) = 0;                      % Mal
lambda_R(34) = 0;                      % Oaa
lambda_R(35) = 0;                      % FADHA
lambda_R(36) = 0;                      % FAD
lambda_R(37) = 0;                      % H
%-------------------------------------------------------------------------
lambda_W(1) = 1;                       % Glucose    
lambda_W(2) = 0.95;                    % Pyruvate
lambda_W(3) = 1;                       % Lactate 
lambda_W(4) = 1;                       % Alanine 
lambda_W(5) = 1;                       % Glycerol
lambda_W(6) = 1;                       % FFA 
lambda_W(7) = 0;                       % CO2 
lambda_W(8) = 0;                       % O2 
lambda_W(9) = 1;                       % G6P
lambda_W(10) = 1;                      % Glycogen
lambda_W(11) = 1;                      % F6P
lambda_W(12) = 1;                      % F16BP
lambda_W(13) = 1;                      % GA3P
lambda_W(14) = 1;                      % 13BPG
lambda_W(15) = 1;                      % PEP
lambda_W(16) = 1;                      % Tglyceride 
lambda_W(17) = 1;                      % Gr3P
lambda_W(18) = 0.95;                   % FAC
lambda_W(19) = 1;                      % PCr
lambda_W(20) = 1;                      % Cr
lambda_W(21) = 0.95699059561;          % ATP
lambda_W(22) = 0.40;                   % ADP
lambda_W(23) = 1;                      % AMP
lambda_W(24) = 0.95;                   % Pi
lambda_W(25) = 0.8;                    % CoA
lambda_W(26) = 0.005;                  % NADH
lambda_W(27) = 0.3;                    % NAD
lambda_W(28) = 0;                      % ACOA
lambda_W(29) = 0;                      % Cit
lambda_W(30) = 0;                      % AKG
lambda_W(31) = 0;                      % SCoA
lambda_W(32) = 0;                      % Suc
lambda_W(33) = 0;                      % Mal
lambda_W(34) = 0;                      % Oaa
lambda_W(35) = 0;                      % FADHA
lambda_W(36) = 0;                      % FAD
lambda_W(37) = 0;                      % H
%**************************************************************************
% This section sets the species concentratin in each domain in each fiber
%--------------------------------------------------------------------------
Cc_R = zeros(50,1);                    % Species concentration in Type I
Cc_W = zeros(50,1);                    % Species concentration in Type II
%==========================================================================
% In Type I fiber
Cc_R(1:6) = 0.8*C_tis(1:6).* omega(1:6).*lambda_R(1:6)/VR_cyt; 
Cc_R(7) = 1.403;                       % CO2 
Cc_R(8) = 0.03375;                      % O2
Cc_R(9) = 0.8*C_tis(9).* omega(9).*lambda_R(9)/VR_cyt; 
Cc_R(10) = 1;                          % G1P
Cc_R(11:28) = 0.8*C_tis(10:27).* omega(10:27).*lambda_R(10:27)/VR_cyt; 

%Cc_R(22) = 0.8*C_tis(21)* omega(21)*lambda_R(21)/VR_cyt; 

Cc_R(29) = 1000*10^(-7.1);                          % G1P
Cc_R(30) = 0.027;                       % O2 
Cc_R(31) = 1.525;                       % CO2
Cc_R(32) = 0.8*C_tis(2).* omega(2).*(1-lambda_R(2))/VR_mit; 
Cc_R(33) = 0.8*C_tis(18).* omega(18).*(1-lambda_R(18))/VR_mit; 
Cc_R(34:35) = 0.8*C_tis(26:27).* omega(26:27).*(1-lambda_R(26:27))/VR_mit; 
Cc_R(36:37) = 0.8*C_tis(21:22).* omega(21:22).*(1-lambda_R(21:22))/VR_mit; 
Cc_R(38:39) = 0.8*C_tis(24:25).* omega(24:25).*(1-lambda_R(24:25))/VR_mit; 
Cc_R(40) =  1000*10^(-7.6);                     % H
Cc_R(41:49) = 0.8*C_tis(28:36).* omega(28:36).*(1-lambda_R(28:36))/VR_mit; 
Cc_R(50) =  0.16;                      % psi
%==========================================================================
% In Type II fiber
Cc_W(1:6) = 0.8*C_tis(1:6).* (1-omega(1:6)).*lambda_W(1:6)/VW_cyt; 
Cc_W(7) = 1.403;                        % CO2 
Cc_W(8) = 0.03375;                      % O2
Cc_W(9) = 0.8*C_tis(9).*(1-omega(9)).*lambda_W(9)/VW_cyt; 
Cc_W(10) = 1;                          % G1P
Cc_W(11:28) = 0.8*C_tis(10:27).*(1-omega(10:27)).*lambda_W(10:27)/VW_cyt; 

Cc_W(22) = 0.8*C_tis(21)*(1-omega(21))*lambda_W(21)/VW_cyt; 

Cc_W(29) = 1000*10^(-7.1);                          % G1P
Cc_W(30) = 0.027;                       % O2 
Cc_W(31) = 1.525;                       % CO2
Cc_W(32) = 0.8*C_tis(2).* (1-omega(2)).*(1-lambda_W(2))/VW_mit; 
Cc_W(33) = 0.8*C_tis(18).* (1-omega(18)).*(1-lambda_W(18))/VW_mit; 
Cc_W(34:35) = 0.8*C_tis(26:27).*(1-omega(26:27)).*(1-lambda_W(26:27))/VW_mit; 
Cc_W(36:37) = 0.8*C_tis(21:22).*(1-omega(21:22)).*(1-lambda_W(21:22))/VW_mit; 
Cc_W(38:39) = 0.8*C_tis(24:25).*(1-omega(24:25)).*(1-lambda_W(24:25))/VW_mit; 
Cc_W(40) =  1000*10^(-7.6);                     % H
Cc_W(41:49) = 0.8*C_tis(28:36).*(1-omega(28:36)).*(1-lambda_W(28:36))/VW_mit; 
Cc_W(50) =  0.16;                     % psi
%**************************************************************************
% This section is to write the values to text files
%--------------------------------------------------------------------------
save Cc0_tissue Cc_R Cc_W
%**************************************************************************
%*****************************End******************************************


